info = {
    "name": "gd",
    "date_order": "DMY",
    "january": [
        "am faoilleach",
        "dhen fhaoilleach",
        "faoi"
    ],
    "february": [
        "an gearran",
        "dhen ghearran",
        "gearr"
    ],
    "march": [
        "am màrt",
        "dhen mhàrt",
        "màrt"
    ],
    "april": [
        "an giblean",
        "dhen ghiblean",
        "gibl"
    ],
    "may": [
        "an cèitean",
        "cèit",
        "dhen chèitean"
    ],
    "june": [
        "an t-ògmhios",
        "dhen ògmhios",
        "ògmh"
    ],
    "july": [
        "an t-iuchar",
        "dhen iuchar",
        "iuch"
    ],
    "august": [
        "an lùnastal",
        "dhen lùnastal",
        "lùna"
    ],
    "september": [
        "an t-sultain",
        "dhen t-sultain",
        "sult"
    ],
    "october": [
        "an dàmhair",
        "dhen dàmhair",
        "dàmh"
    ],
    "november": [
        "an t-samhain",
        "dhen t-samhain",
        "samh"
    ],
    "december": [
        "an dùbhlachd",
        "dhen dùbhlachd",
        "dùbh"
    ],
    "monday": [
        "dil",
        "diluain"
    ],
    "tuesday": [
        "dim",
        "dimàirt"
    ],
    "wednesday": [
        "dic",
        "diciadain"
    ],
    "thursday": [
        "dia",
        "diardaoin"
    ],
    "friday": [
        "dih",
        "dihaoine"
    ],
    "saturday": [
        "dis",
        "disathairne"
    ],
    "sunday": [
        "did",
        "didòmhnaich"
    ],
    "am": [
        "m"
    ],
    "pm": [
        "f"
    ],
    "year": [
        "bl",
        "blia",
        "bliadhna"
    ],
    "month": [
        "mì",
        "mìos"
    ],
    "week": [
        "seachd",
        "seachdain",
        "sn"
    ],
    "day": [
        "latha",
        "là"
    ],
    "hour": [
        "u",
        "uair",
        "uair a thìde"
    ],
    "minute": [
        "m",
        "mion",
        "mionaid"
    ],
    "second": [
        "d",
        "diog"
    ],
    "relative-type": {
        "0 day ago": [
            "an-diugh"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "am mì seo",
            "am mìos seo"
        ],
        "0 second ago": [
            "an-dràsta"
        ],
        "0 week ago": [
            "an t-seachd seo",
            "an t-seachdain seo",
            "an t-sn seo"
        ],
        "0 year ago": [
            "am bl",
            "am bliadhna"
        ],
        "1 day ago": [
            "an-dè"
        ],
        "1 month ago": [
            "am mìos sa chaidh",
            "am mìos seo chaidh",
            "mì ch"
        ],
        "1 week ago": [
            "an t-seachdain seo chaidh",
            "seachd sa chaidh",
            "sn ch"
        ],
        "1 year ago": [
            "an-uir",
            "an-uiridh"
        ],
        "in 1 day": [
            "a-màireach"
        ],
        "in 1 month": [
            "an ath-mhìos",
            "ath-mhì"
        ],
        "in 1 week": [
            "an ath-sheachd",
            "an ath-sheachdain",
            "ath-shn"
        ],
        "in 1 year": [
            "an ath-bhl",
            "an ath-bhliadhna"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "o (\\d+[.,]?\\d*) là",
            "(\\d+[.,]?\\d*) latha air ais"
        ],
        "\\1 hour ago": [
            "o (\\d+[.,]?\\d*) uair",
            "(\\d+[.,]?\\d*) uair a thìde air ais"
        ],
        "\\1 minute ago": [
            "o (\\d+[.,]?\\d*) mhion",
            "o (\\d+[.,]?\\d*) mion",
            "(\\d+[.,]?\\d*) mhionaid air ais",
            "(\\d+[.,]?\\d*) mionaid air ais"
        ],
        "\\1 month ago": [
            "o (\\d+[.,]?\\d*) mhìos",
            "o (\\d+[.,]?\\d*) mìos",
            "(\\d+[.,]?\\d*) mhìos air ais",
            "(\\d+[.,]?\\d*) mìos air ais"
        ],
        "\\1 second ago": [
            "o (\\d+[.,]?\\d*) diog",
            "(\\d+[.,]?\\d*) diog air ais"
        ],
        "\\1 week ago": [
            "o (\\d+[.,]?\\d*) seachd",
            "o (\\d+[.,]?\\d*) sheachd",
            "(\\d+[.,]?\\d*) seachdain air ais"
        ],
        "\\1 year ago": [
            "o (\\d+[.,]?\\d*) bhlia",
            "o (\\d+[.,]?\\d*) blia",
            "(\\d+[.,]?\\d*) bhliadhna air ais",
            "(\\d+[.,]?\\d*) bliadhna air ais"
        ],
        "in \\1 day": [
            "an ceann (\\d+[.,]?\\d*) latha",
            "an (\\d+[.,]?\\d*) là"
        ],
        "in \\1 hour": [
            "an ceann (\\d+[.,]?\\d*) uair a thìde",
            "an (\\d+[.,]?\\d*) uair"
        ],
        "in \\1 minute": [
            "an ceann (\\d+[.,]?\\d*) mhionaid",
            "an ceann (\\d+[.,]?\\d*) mionaid",
            "an (\\d+[.,]?\\d*) mhion",
            "an (\\d+[.,]?\\d*) mion"
        ],
        "in \\1 month": [
            "an ceann (\\d+[.,]?\\d*) mhìosa",
            "an ceann (\\d+[.,]?\\d*) mìosa",
            "an (\\d+[.,]?\\d*) mhìos",
            "an (\\d+[.,]?\\d*) mìos"
        ],
        "in \\1 second": [
            "an ceann (\\d+[.,]?\\d*) diog",
            "an (\\d+[.,]?\\d*) diog"
        ],
        "in \\1 week": [
            "an ceann (\\d+[.,]?\\d*) seachdain",
            "an (\\d+[.,]?\\d*) seachd",
            "an (\\d+[.,]?\\d*) sheachd"
        ],
        "in \\1 year": [
            "an ceann (\\d+[.,]?\\d*) bhliadhna",
            "an ceann (\\d+[.,]?\\d*) bliadhna",
            "an (\\d+[.,]?\\d*) bhlia",
            "an (\\d+[.,]?\\d*) blia"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
