info = {
    "name": "lag",
    "date_order": "DMY",
    "january": [
        "fúngatɨ",
        "kʉfúngatɨ"
    ],
    "february": [
        "kʉnaanɨ",
        "naanɨ"
    ],
    "march": [
        "keenda",
        "kʉkeenda"
    ],
    "april": [
        "ikúmi",
        "kwiikumi"
    ],
    "may": [
        "inyambala",
        "kwiinyambála"
    ],
    "june": [
        "idwaata",
        "kwiidwaata"
    ],
    "july": [
        "kʉmʉʉnchɨ",
        "mʉʉnchɨ"
    ],
    "august": [
        "kʉvɨɨrɨ",
        "vɨɨrɨ"
    ],
    "september": [
        "kʉsaatʉ",
        "saatʉ"
    ],
    "october": [
        "inyi",
        "kwiinyi"
    ],
    "november": [
        "kʉsaano",
        "saano"
    ],
    "december": [
        "kʉsasatʉ",
        "sasatʉ"
    ],
    "monday": [
        "jumatátu",
        "táatu"
    ],
    "tuesday": [
        "jumaíne",
        "íne"
    ],
    "wednesday": [
        "jumatáano",
        "táano"
    ],
    "thursday": [
        "alamíisi",
        "alh"
    ],
    "friday": [
        "ijm",
        "ijumáa"
    ],
    "saturday": [
        "jumamóosi",
        "móosi"
    ],
    "sunday": [
        "jumapíiri",
        "píili"
    ],
    "am": [
        "too"
    ],
    "pm": [
        "muu"
    ],
    "year": [
        "mwaáka"
    ],
    "month": [
        "mweéri"
    ],
    "week": [
        "wíiki"
    ],
    "day": [
        "sikʉ"
    ],
    "hour": [
        "sáa"
    ],
    "minute": [
        "dakíka"
    ],
    "second": [
        "sekúunde"
    ],
    "relative-type": {
        "0 day ago": [
            "isikʉ"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "niijo"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "lamʉtoondo"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
