info = {
    "name": "eo",
    "date_order": "YMD",
    "january": [
        "jan",
        "januaro"
    ],
    "february": [
        "feb",
        "februaro"
    ],
    "march": [
        "mar",
        "marto"
    ],
    "april": [
        "apr",
        "aprilo"
    ],
    "may": [
        "maj",
        "majo"
    ],
    "june": [
        "jun",
        "junio"
    ],
    "july": [
        "jul",
        "julio"
    ],
    "august": [
        "aŭg",
        "aŭgusto"
    ],
    "september": [
        "sep",
        "septembro"
    ],
    "october": [
        "okt",
        "oktobro"
    ],
    "november": [
        "nov",
        "novembro"
    ],
    "december": [
        "dec",
        "decembro"
    ],
    "monday": [
        "lu",
        "lundo"
    ],
    "tuesday": [
        "ma",
        "mardo"
    ],
    "wednesday": [
        "me",
        "merkredo"
    ],
    "thursday": [
        "ĵa",
        "ĵaŭdo"
    ],
    "friday": [
        "ve",
        "vendredo"
    ],
    "saturday": [
        "sa",
        "sabato"
    ],
    "sunday": [
        "di",
        "dimanĉo"
    ],
    "am": [
        "atm"
    ],
    "pm": [
        "ptm"
    ],
    "year": [
        "year"
    ],
    "month": [
        "month"
    ],
    "week": [
        "week"
    ],
    "day": [
        "day"
    ],
    "hour": [
        "hour"
    ],
    "minute": [
        "minute"
    ],
    "second": [
        "second"
    ],
    "relative-type": {
        "0 day ago": [
            "today"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "yesterday"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "tomorrow"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
