info = {
    "name": "yav",
    "date_order": "DMY",
    "january": [
        "o1",
        "pikítíkítie, oólí ú kutúan"
    ],
    "february": [
        "o2",
        "siɛyɛ́, oóli ú kándíɛ"
    ],
    "march": [
        "o3",
        "ɔnsúmbɔl, oóli ú kátátúɛ"
    ],
    "april": [
        "mesiŋ, oóli ú kénie",
        "o4"
    ],
    "may": [
        "ensil, oóli ú kátánuɛ",
        "o5"
    ],
    "june": [
        "o6",
        "ɔsɔn"
    ],
    "july": [
        "efute",
        "o7"
    ],
    "august": [
        "o8",
        "pisuyú"
    ],
    "september": [
        "imɛŋ i puɔs",
        "o9"
    ],
    "october": [
        "imɛŋ i putúk,oóli ú kátíɛ",
        "o10"
    ],
    "november": [
        "makandikɛ",
        "o11"
    ],
    "december": [
        "o12",
        "pilɔndɔ́"
    ],
    "monday": [
        "md",
        "móndie"
    ],
    "tuesday": [
        "muányáŋmóndie",
        "mw"
    ],
    "wednesday": [
        "et",
        "metúkpíápɛ"
    ],
    "thursday": [
        "kl",
        "kúpélimetúkpiapɛ"
    ],
    "friday": [
        "feléte",
        "fl"
    ],
    "saturday": [
        "ss",
        "séselé"
    ],
    "sunday": [
        "sd",
        "sɔ́ndiɛ"
    ],
    "am": [
        "kiɛmɛ́ɛm"
    ],
    "pm": [
        "kisɛ́ndɛ"
    ],
    "year": [
        "yɔɔŋ"
    ],
    "month": [
        "oóli"
    ],
    "week": [
        "sɔ́ndiɛ"
    ],
    "day": [
        "puɔ́sɛ́"
    ],
    "hour": [
        "kisikɛl,"
    ],
    "minute": [
        "minít"
    ],
    "second": [
        "síkɛn"
    ],
    "relative-type": {
        "0 day ago": [
            "ínaan"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "púyoó"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "nakinyám"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
