info = {
    "name": "sbp",
    "date_order": "DMY",
    "january": [
        "mup",
        "mupalangulwa"
    ],
    "february": [
        "mwi",
        "mwitope"
    ],
    "march": [
        "msh",
        "mushende"
    ],
    "april": [
        "mun",
        "munyi"
    ],
    "may": [
        "mag",
        "mushende magali"
    ],
    "june": [
        "muj",
        "mujimbi"
    ],
    "july": [
        "msp",
        "mushipepo"
    ],
    "august": [
        "mpg",
        "mupuguto"
    ],
    "september": [
        "munyense",
        "mye"
    ],
    "october": [
        "mok",
        "mokhu"
    ],
    "november": [
        "mus",
        "musongandembwe"
    ],
    "december": [
        "muh",
        "muhaano"
    ],
    "monday": [
        "jtt",
        "jumatatu"
    ],
    "tuesday": [
        "jnn",
        "jumanne"
    ],
    "wednesday": [
        "jtn",
        "jumatano"
    ],
    "thursday": [
        "alahamisi",
        "alh"
    ],
    "friday": [
        "iju",
        "ijumaa"
    ],
    "saturday": [
        "jmo",
        "jumamosi"
    ],
    "sunday": [
        "mul",
        "mulungu"
    ],
    "am": [
        "lwamilawu"
    ],
    "pm": [
        "pashamihe"
    ],
    "year": [
        "mwakha"
    ],
    "month": [
        "mwesi"
    ],
    "week": [
        "ilijuma"
    ],
    "day": [
        "lusiku"
    ],
    "hour": [
        "ilisala"
    ],
    "minute": [
        "idakika"
    ],
    "second": [
        "isekunde"
    ],
    "relative-type": {
        "0 day ago": [
            "ineng'uni"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "imehe"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "pamulaawu"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
