info = {
    "name": "ff",
    "date_order": "DMY",
    "january": [
        "sii",
        "siilo"
    ],
    "february": [
        "col",
        "colte"
    ],
    "march": [
        "mbo",
        "mbooy"
    ],
    "april": [
        "see",
        "seeɗto"
    ],
    "may": [
        "duu",
        "duujal"
    ],
    "june": [
        "kor",
        "korse"
    ],
    "july": [
        "mor",
        "morso"
    ],
    "august": [
        "juk",
        "juko"
    ],
    "september": [
        "siilto",
        "slt"
    ],
    "october": [
        "yar",
        "yarkomaa"
    ],
    "november": [
        "jol",
        "jolal"
    ],
    "december": [
        "bow",
        "bowte"
    ],
    "monday": [
        "aaɓ",
        "aaɓnde"
    ],
    "tuesday": [
        "maw",
        "mawbaare"
    ],
    "wednesday": [
        "nje",
        "njeslaare"
    ],
    "thursday": [
        "naa",
        "naasaande"
    ],
    "friday": [
        "mawnde",
        "mwd"
    ],
    "saturday": [
        "hbi",
        "hoore-biir"
    ],
    "sunday": [
        "dew",
        "dewo"
    ],
    "am": [
        "subaka"
    ],
    "pm": [
        "kikiiɗe"
    ],
    "year": [
        "hitaande"
    ],
    "month": [
        "lewru"
    ],
    "week": [
        "yontere"
    ],
    "day": [
        "ñalnde"
    ],
    "hour": [
        "waktu"
    ],
    "minute": [
        "hoƴom"
    ],
    "second": [
        "majaango"
    ],
    "relative-type": {
        "0 day ago": [
            "hannde"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "haŋki"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "jaŋngo"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {
        "ff-CM": {
            "name": "ff-CM"
        },
        "ff-GN": {
            "name": "ff-GN"
        },
        "ff-MR": {
            "name": "ff-MR"
        }
    },
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
