info = {
    "name": "shi-Tfng",
    "date_order": "DMY",
    "january": [
        "ⵉⵏⵏ",
        "ⵉⵏⵏⴰⵢⵔ"
    ],
    "february": [
        "ⴱⵕⴰ",
        "ⴱⵕⴰⵢⵕ"
    ],
    "march": [
        "ⵎⴰⵕ",
        "ⵎⴰⵕⵚ"
    ],
    "april": [
        "ⵉⴱⵔ",
        "ⵉⴱⵔⵉⵔ"
    ],
    "may": [
        "ⵎⴰⵢ",
        "ⵎⴰⵢⵢⵓ"
    ],
    "june": [
        "ⵢⵓⵏ",
        "ⵢⵓⵏⵢⵓ"
    ],
    "july": [
        "ⵢⵓⵍ",
        "ⵢⵓⵍⵢⵓⵣ"
    ],
    "august": [
        "ⵖⵓⵛ",
        "ⵖⵓⵛⵜ"
    ],
    "september": [
        "ⵛⵓⵜ",
        "ⵛⵓⵜⴰⵏⴱⵉⵔ"
    ],
    "october": [
        "ⴽⵜⵓ",
        "ⴽⵜⵓⴱⵔ"
    ],
    "november": [
        "ⵏⵓⵡ",
        "ⵏⵓⵡⴰⵏⴱⵉⵔ"
    ],
    "december": [
        "ⴷⵓⵊ",
        "ⴷⵓⵊⴰⵏⴱⵉⵔ"
    ],
    "monday": [
        "ⴰⵢⵏ",
        "ⴰⵢⵏⴰⵙ"
    ],
    "tuesday": [
        "ⴰⵙⵉ",
        "ⴰⵙⵉⵏⴰⵙ"
    ],
    "wednesday": [
        "ⴰⴽⵕ",
        "ⴰⴽⵕⴰⵙ"
    ],
    "thursday": [
        "ⴰⴽⵡ",
        "ⴰⴽⵡⴰⵙ"
    ],
    "friday": [
        "ⴰⵙⵉⵎ",
        "ⵙⵉⵎⵡⴰⵙ"
    ],
    "saturday": [
        "ⴰⵙⵉⴹ",
        "ⴰⵙⵉⴹⵢⴰⵙ"
    ],
    "sunday": [
        "ⴰⵙⴰ",
        "ⴰⵙⴰⵎⴰⵙ"
    ],
    "am": [
        "ⵜⵉⴼⴰⵡⵜ"
    ],
    "pm": [
        "ⵜⴰⴷⴳⴳⵯⴰⵜ"
    ],
    "year": [
        "ⴰⵙⴳⴳⵯⴰⵙ"
    ],
    "month": [
        "ⴰⵢⵢⵓⵔ"
    ],
    "week": [
        "ⵉⵎⴰⵍⴰⵙⵙ"
    ],
    "day": [
        "ⴰⵙⵙ"
    ],
    "hour": [
        "ⵜⴰⵙⵔⴰⴳⵜ"
    ],
    "minute": [
        "ⵜⵓⵙⴷⵉⴷⵜ"
    ],
    "second": [
        "ⵜⴰⵙⵉⵏⵜ"
    ],
    "relative-type": {
        "0 day ago": [
            "ⴰⵙⵙⴰ"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "ⵉⴹⵍⵍⵉ"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "ⴰⵙⴽⴽⴰ"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
