info = {
    "name": "is",
    "date_order": "DMY",
    "january": [
        "jan",
        "janúar"
    ],
    "february": [
        "feb",
        "febrúar"
    ],
    "march": [
        "mar",
        "mars"
    ],
    "april": [
        "apr",
        "apríl"
    ],
    "may": [
        "maí"
    ],
    "june": [
        "jún",
        "júní"
    ],
    "july": [
        "júl",
        "júlí"
    ],
    "august": [
        "ágú",
        "ágúst"
    ],
    "september": [
        "sep",
        "september"
    ],
    "october": [
        "okt",
        "október"
    ],
    "november": [
        "nóv",
        "nóvember"
    ],
    "december": [
        "des",
        "desember"
    ],
    "monday": [
        "mán",
        "mánudagur"
    ],
    "tuesday": [
        "þri",
        "þriðjudagur"
    ],
    "wednesday": [
        "mið",
        "miðvikudagur"
    ],
    "thursday": [
        "fim",
        "fimmtudagur"
    ],
    "friday": [
        "fös",
        "föstudagur"
    ],
    "saturday": [
        "lau",
        "laugardagur"
    ],
    "sunday": [
        "sun",
        "sunnudagur"
    ],
    "am": [
        "fh"
    ],
    "pm": [
        "eh"
    ],
    "year": [
        "ár"
    ],
    "month": [
        "mán",
        "mánuður"
    ],
    "week": [
        "v",
        "vika"
    ],
    "day": [
        "d",
        "dagur"
    ],
    "hour": [
        "klst",
        "klukkustund"
    ],
    "minute": [
        "mín",
        "mínúta"
    ],
    "second": [
        "sek",
        "sekúnda"
    ],
    "relative-type": {
        "0 day ago": [
            "í dag"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "í þessum mán",
            "í þessum mánuði"
        ],
        "0 second ago": [
            "núna"
        ],
        "0 week ago": [
            "í þessari viku"
        ],
        "0 year ago": [
            "á þessu ári"
        ],
        "1 day ago": [
            "í gær"
        ],
        "1 month ago": [
            "í síðasta mán",
            "í síðasta mánuði"
        ],
        "1 week ago": [
            "í síðustu viku"
        ],
        "1 year ago": [
            "á síðasta ári"
        ],
        "in 1 day": [
            "á morgun"
        ],
        "in 1 month": [
            "í næsta mán",
            "í næsta mánuði"
        ],
        "in 1 week": [
            "í næstu viku"
        ],
        "in 1 year": [
            "á næsta ári"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "fyrir (\\d+[.,]?\\d*) degi",
            "fyrir (\\d+[.,]?\\d*) dögum"
        ],
        "\\1 hour ago": [
            "fyrir (\\d+[.,]?\\d*) klst",
            "fyrir (\\d+[.,]?\\d*) klukkustund",
            "fyrir (\\d+[.,]?\\d*) klukkustundum"
        ],
        "\\1 minute ago": [
            "fyrir (\\d+[.,]?\\d*) mín",
            "fyrir (\\d+[.,]?\\d*) mínútu",
            "fyrir (\\d+[.,]?\\d*) mínútum"
        ],
        "\\1 month ago": [
            "fyrir (\\d+[.,]?\\d*) mán",
            "fyrir (\\d+[.,]?\\d*) mánuði",
            "fyrir (\\d+[.,]?\\d*) mánuðum"
        ],
        "\\1 second ago": [
            "fyrir (\\d+[.,]?\\d*) sek",
            "fyrir (\\d+[.,]?\\d*) sekúndu",
            "fyrir (\\d+[.,]?\\d*) sekúndum"
        ],
        "\\1 week ago": [
            "fyrir (\\d+[.,]?\\d*) viku",
            "fyrir (\\d+[.,]?\\d*) vikum"
        ],
        "\\1 year ago": [
            "fyrir (\\d+[.,]?\\d*) ári",
            "fyrir (\\d+[.,]?\\d*) árum"
        ],
        "in \\1 day": [
            "eftir (\\d+[.,]?\\d*) dag",
            "eftir (\\d+[.,]?\\d*) daga"
        ],
        "in \\1 hour": [
            "eftir (\\d+[.,]?\\d*) klst",
            "eftir (\\d+[.,]?\\d*) klukkustund",
            "eftir (\\d+[.,]?\\d*) klukkustundir"
        ],
        "in \\1 minute": [
            "eftir (\\d+[.,]?\\d*) mín",
            "eftir (\\d+[.,]?\\d*) mínútu",
            "eftir (\\d+[.,]?\\d*) mínútur"
        ],
        "in \\1 month": [
            "eftir (\\d+[.,]?\\d*) mán",
            "eftir (\\d+[.,]?\\d*) mánuð",
            "eftir (\\d+[.,]?\\d*) mánuði"
        ],
        "in \\1 second": [
            "eftir (\\d+[.,]?\\d*) sek",
            "eftir (\\d+[.,]?\\d*) sekúndu",
            "eftir (\\d+[.,]?\\d*) sekúndur"
        ],
        "in \\1 week": [
            "eftir (\\d+[.,]?\\d*) viku",
            "eftir (\\d+[.,]?\\d*) vikur"
        ],
        "in \\1 year": [
            "eftir (\\d+[.,]?\\d*) ár"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
