info = {
    "name": "ti",
    "date_order": "DMY",
    "january": [
        "ጥሪ"
    ],
    "february": [
        "ለካ",
        "ለካቲት"
    ],
    "march": [
        "መጋ",
        "መጋቢት"
    ],
    "april": [
        "ሚያ",
        "ሚያዝያ"
    ],
    "may": [
        "ግን",
        "ግንቦት"
    ],
    "june": [
        "ሰነ"
    ],
    "july": [
        "ሓም",
        "ሓምለ"
    ],
    "august": [
        "ነሓ",
        "ነሓሰ"
    ],
    "september": [
        "መስ",
        "መስከረም"
    ],
    "october": [
        "ጥቅ",
        "ጥቅምቲ"
    ],
    "november": [
        "ሕዳ",
        "ሕዳር"
    ],
    "december": [
        "ታሕ",
        "ታሕሳስ"
    ],
    "monday": [
        "ሰኑ",
        "ሰኑይ"
    ],
    "tuesday": [
        "ሠሉስ",
        "ሰሉ",
        "ሰሉስ"
    ],
    "wednesday": [
        "ረቡ",
        "ረቡዕ"
    ],
    "thursday": [
        "ሓሙ",
        "ሓሙስ",
        "ኃሙስ"
    ],
    "friday": [
        "ዓር",
        "ዓርቢ"
    ],
    "saturday": [
        "ቀዳ",
        "ቀዳም"
    ],
    "sunday": [
        "ሰን",
        "ሰንበት"
    ],
    "am": [
        "ንጉሆ ሰዓተ"
    ],
    "pm": [
        "ድሕር ሰዓት"
    ],
    "year": [
        "year"
    ],
    "month": [
        "month"
    ],
    "week": [
        "week"
    ],
    "day": [
        "day"
    ],
    "hour": [
        "hour"
    ],
    "minute": [
        "minute"
    ],
    "second": [
        "second"
    ],
    "relative-type": {
        "0 day ago": [
            "today"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "yesterday"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "tomorrow"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {
        "ti-ER": {
            "name": "ti-ER"
        }
    },
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
