info = {
    "name": "dje",
    "date_order": "DMY",
    "january": [
        "žan",
        "žanwiye"
    ],
    "february": [
        "fee",
        "feewiriye"
    ],
    "march": [
        "mar",
        "marsi"
    ],
    "april": [
        "awi",
        "awiril"
    ],
    "may": [
        "me"
    ],
    "june": [
        "žuw",
        "žuweŋ"
    ],
    "july": [
        "žuy",
        "žuyye"
    ],
    "august": [
        "ut"
    ],
    "september": [
        "sek",
        "sektanbur"
    ],
    "october": [
        "okt",
        "oktoobur"
    ],
    "november": [
        "noo",
        "noowanbur"
    ],
    "december": [
        "dee",
        "deesanbur"
    ],
    "monday": [
        "ati",
        "atinni"
    ],
    "tuesday": [
        "ata",
        "atalaata"
    ],
    "wednesday": [
        "ala",
        "alarba"
    ],
    "thursday": [
        "alhamisi",
        "alm"
    ],
    "friday": [
        "alz",
        "alzuma"
    ],
    "saturday": [
        "asi",
        "asibti"
    ],
    "sunday": [
        "alh",
        "alhadi"
    ],
    "am": [
        "subbaahi"
    ],
    "pm": [
        "zaarikay b"
    ],
    "year": [
        "jiiri"
    ],
    "month": [
        "handu"
    ],
    "week": [
        "hebu"
    ],
    "day": [
        "zaari"
    ],
    "hour": [
        "guuru"
    ],
    "minute": [
        "miniti"
    ],
    "second": [
        "miti"
    ],
    "relative-type": {
        "0 day ago": [
            "hõo"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "bi"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "suba"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
