info = {
    "name": "ig",
    "date_order": "DMY",
    "january": [
        "jen",
        "jenụwarị"
    ],
    "february": [
        "feb",
        "febrụwarị"
    ],
    "march": [
        "maa",
        "maachị"
    ],
    "april": [
        "epr",
        "eprel"
    ],
    "may": [
        "mee"
    ],
    "june": [
        "juu",
        "juun"
    ],
    "july": [
        "jul",
        "julaị"
    ],
    "august": [
        "ọgọ",
        "ọgọọst"
    ],
    "september": [
        "sep",
        "septemba"
    ],
    "october": [
        "ọkt",
        "ọktoba"
    ],
    "november": [
        "nov",
        "novemba"
    ],
    "december": [
        "dis",
        "disemba"
    ],
    "monday": [
        "mọn",
        "mọnde"
    ],
    "tuesday": [
        "tiu",
        "tiuzdee"
    ],
    "wednesday": [
        "wen",
        "wenezdee"
    ],
    "thursday": [
        "tọọ",
        "tọọzdee"
    ],
    "friday": [
        "fraị",
        "fraịdee"
    ],
    "saturday": [
        "sat",
        "satọdee"
    ],
    "sunday": [
        "mbọsị ụka",
        "ụka"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "afọ"
    ],
    "month": [
        "ọnwa"
    ],
    "week": [
        "izu"
    ],
    "day": [
        "ụbọchị"
    ],
    "hour": [
        "elekere"
    ],
    "minute": [
        "nkeji"
    ],
    "second": [
        "nkejinta"
    ],
    "relative-type": {
        "0 day ago": [
            "taata"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "nnyaafụ"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "echi"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
