info = {
    "name": "agq",
    "date_order": "DMY",
    "january": [
        "ndzɔ̀ŋɔ̀nùm",
        "nùm"
    ],
    "february": [
        "kɨz",
        "ndzɔ̀ŋɔ̀kɨ̀zùʔ"
    ],
    "march": [
        "ndzɔ̀ŋɔ̀tɨ̀dʉ̀ghà",
        "tɨd"
    ],
    "april": [
        "ndzɔ̀ŋɔ̀tǎafʉ̄ghā",
        "taa"
    ],
    "may": [
        "ndzɔ̀ŋèsèe",
        "see"
    ],
    "june": [
        "ndzɔ̀ŋɔ̀nzùghò",
        "nzu"
    ],
    "july": [
        "dum",
        "ndzɔ̀ŋɔ̀dùmlo"
    ],
    "august": [
        "fɔe",
        "ndzɔ̀ŋɔ̀kwîfɔ̀e"
    ],
    "september": [
        "dzu",
        "ndzɔ̀ŋɔ̀tɨ̀fʉ̀ghàdzughù"
    ],
    "october": [
        "lɔm",
        "ndzɔ̀ŋɔ̀ghǔuwelɔ̀m"
    ],
    "november": [
        "kaa",
        "ndzɔ̀ŋɔ̀chwaʔàkaa wo"
    ],
    "december": [
        "fwo",
        "ndzɔ̀ŋèfwòo"
    ],
    "monday": [
        "kpa",
        "tsuʔukpà"
    ],
    "tuesday": [
        "ghɔ",
        "tsuʔughɔe"
    ],
    "wednesday": [
        "tsuʔutɔ̀mlò",
        "tɔm"
    ],
    "thursday": [
        "tsuʔumè",
        "ume"
    ],
    "friday": [
        "ghɨ",
        "tsuʔughɨ̂m"
    ],
    "saturday": [
        "dzk",
        "tsuʔndzɨkɔʔɔ"
    ],
    "sunday": [
        "nts",
        "tsuʔntsɨ"
    ],
    "am": [
        "ag"
    ],
    "pm": [
        "ak"
    ],
    "year": [
        "kɨnûm"
    ],
    "month": [
        "ndzɔŋ"
    ],
    "week": [
        "ewɨn"
    ],
    "day": [
        "utsuʔ"
    ],
    "hour": [
        "tàm"
    ],
    "minute": [
        "menè"
    ],
    "second": [
        "sɛkɔ̀n"
    ],
    "relative-type": {
        "0 day ago": [
            "nɛ"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "ā zūɛɛ"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "tsʉtsʉ"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
