info = {
    "name": "ksf",
    "date_order": "DMY",
    "january": [
        "ŋ1",
        "ŋwíí a ntɔ́ntɔ"
    ],
    "february": [
        "ŋ2",
        "ŋwíí akǝ bɛ́ɛ"
    ],
    "march": [
        "ŋ3",
        "ŋwíí akǝ ráá"
    ],
    "april": [
        "ŋ4",
        "ŋwíí akǝ nin"
    ],
    "may": [
        "ŋ5",
        "ŋwíí akǝ táan"
    ],
    "june": [
        "ŋ6",
        "ŋwíí akǝ táafɔk"
    ],
    "july": [
        "ŋ7",
        "ŋwíí akǝ táabɛɛ"
    ],
    "august": [
        "ŋ8",
        "ŋwíí akǝ táaraa"
    ],
    "september": [
        "ŋ9",
        "ŋwíí akǝ táanin"
    ],
    "october": [
        "ŋ10",
        "ŋwíí akǝ ntɛk"
    ],
    "november": [
        "ŋ11",
        "ŋwíí akǝ ntɛk di bɔ́k"
    ],
    "december": [
        "ŋ12",
        "ŋwíí akǝ ntɛk di bɛ́ɛ"
    ],
    "monday": [
        "lǝn",
        "lǝndí"
    ],
    "tuesday": [
        "maa",
        "maadí"
    ],
    "wednesday": [
        "mɛk",
        "mɛkrɛdí"
    ],
    "thursday": [
        "jǝǝ",
        "jǝǝdí"
    ],
    "friday": [
        "júm",
        "júmbá"
    ],
    "saturday": [
        "sam",
        "samdí"
    ],
    "sunday": [
        "sɔ́n",
        "sɔ́ndǝ"
    ],
    "am": [
        "sárúwá"
    ],
    "pm": [
        "cɛɛ́nko"
    ],
    "year": [
        "bǝk"
    ],
    "month": [
        "ŋwíí"
    ],
    "week": [
        "sɔ́ndǝ"
    ],
    "day": [
        "ŋwós"
    ],
    "hour": [
        "cámɛɛn"
    ],
    "minute": [
        "mǝnít"
    ],
    "second": [
        "háu"
    ],
    "relative-type": {
        "0 day ago": [
            "gɛ́ɛnǝ"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "rinkɔɔ́"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "ridúrǝ́"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
